# HOW-TO Support Research & Jupyter Notebook Tasks

The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this document are to be interpreted as described in [RFC 2119](https://www.ietf.org/rfc/rfc2119.txt).

- The Semantic Web / RDF Ecosystem: You SHOULD use the `rdf11-primer` and `owl2-overview` specifications so that you don't overlook relevent references.
- Description Logic (DL) Reasoning: You MUST assume that the notebook will use the `rdflib-reasoning-engine` package.
